# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.15.4
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class CableDesignConnectionListObject(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'cable_design': 'ItemDomainCableDesign',
        'item_connector': 'ItemConnector',
        'cable_relationship': 'ItemElementRelationship',
        'md_item': 'ItemDomainMachineDesign',
        'md_connector': 'ItemConnector',
        'item_connector_name': 'str',
        'md_item_name': 'str',
        'md_connector_name': 'str'
    }

    attribute_map = {
        'cable_design': 'cableDesign',
        'item_connector': 'itemConnector',
        'cable_relationship': 'cableRelationship',
        'md_item': 'mdItem',
        'md_connector': 'mdConnector',
        'item_connector_name': 'itemConnectorName',
        'md_item_name': 'mdItemName',
        'md_connector_name': 'mdConnectorName'
    }

    def __init__(self, cable_design=None, item_connector=None, cable_relationship=None, md_item=None, md_connector=None, item_connector_name=None, md_item_name=None, md_connector_name=None, local_vars_configuration=None):  # noqa: E501
        """CableDesignConnectionListObject - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._cable_design = None
        self._item_connector = None
        self._cable_relationship = None
        self._md_item = None
        self._md_connector = None
        self._item_connector_name = None
        self._md_item_name = None
        self._md_connector_name = None
        self.discriminator = None

        if cable_design is not None:
            self.cable_design = cable_design
        if item_connector is not None:
            self.item_connector = item_connector
        if cable_relationship is not None:
            self.cable_relationship = cable_relationship
        if md_item is not None:
            self.md_item = md_item
        if md_connector is not None:
            self.md_connector = md_connector
        if item_connector_name is not None:
            self.item_connector_name = item_connector_name
        if md_item_name is not None:
            self.md_item_name = md_item_name
        if md_connector_name is not None:
            self.md_connector_name = md_connector_name

    @property
    def cable_design(self):
        """Gets the cable_design of this CableDesignConnectionListObject.  # noqa: E501


        :return: The cable_design of this CableDesignConnectionListObject.  # noqa: E501
        :rtype: ItemDomainCableDesign
        """
        return self._cable_design

    @cable_design.setter
    def cable_design(self, cable_design):
        """Sets the cable_design of this CableDesignConnectionListObject.


        :param cable_design: The cable_design of this CableDesignConnectionListObject.  # noqa: E501
        :type: ItemDomainCableDesign
        """

        self._cable_design = cable_design

    @property
    def item_connector(self):
        """Gets the item_connector of this CableDesignConnectionListObject.  # noqa: E501


        :return: The item_connector of this CableDesignConnectionListObject.  # noqa: E501
        :rtype: ItemConnector
        """
        return self._item_connector

    @item_connector.setter
    def item_connector(self, item_connector):
        """Sets the item_connector of this CableDesignConnectionListObject.


        :param item_connector: The item_connector of this CableDesignConnectionListObject.  # noqa: E501
        :type: ItemConnector
        """

        self._item_connector = item_connector

    @property
    def cable_relationship(self):
        """Gets the cable_relationship of this CableDesignConnectionListObject.  # noqa: E501


        :return: The cable_relationship of this CableDesignConnectionListObject.  # noqa: E501
        :rtype: ItemElementRelationship
        """
        return self._cable_relationship

    @cable_relationship.setter
    def cable_relationship(self, cable_relationship):
        """Sets the cable_relationship of this CableDesignConnectionListObject.


        :param cable_relationship: The cable_relationship of this CableDesignConnectionListObject.  # noqa: E501
        :type: ItemElementRelationship
        """

        self._cable_relationship = cable_relationship

    @property
    def md_item(self):
        """Gets the md_item of this CableDesignConnectionListObject.  # noqa: E501


        :return: The md_item of this CableDesignConnectionListObject.  # noqa: E501
        :rtype: ItemDomainMachineDesign
        """
        return self._md_item

    @md_item.setter
    def md_item(self, md_item):
        """Sets the md_item of this CableDesignConnectionListObject.


        :param md_item: The md_item of this CableDesignConnectionListObject.  # noqa: E501
        :type: ItemDomainMachineDesign
        """

        self._md_item = md_item

    @property
    def md_connector(self):
        """Gets the md_connector of this CableDesignConnectionListObject.  # noqa: E501


        :return: The md_connector of this CableDesignConnectionListObject.  # noqa: E501
        :rtype: ItemConnector
        """
        return self._md_connector

    @md_connector.setter
    def md_connector(self, md_connector):
        """Sets the md_connector of this CableDesignConnectionListObject.


        :param md_connector: The md_connector of this CableDesignConnectionListObject.  # noqa: E501
        :type: ItemConnector
        """

        self._md_connector = md_connector

    @property
    def item_connector_name(self):
        """Gets the item_connector_name of this CableDesignConnectionListObject.  # noqa: E501


        :return: The item_connector_name of this CableDesignConnectionListObject.  # noqa: E501
        :rtype: str
        """
        return self._item_connector_name

    @item_connector_name.setter
    def item_connector_name(self, item_connector_name):
        """Sets the item_connector_name of this CableDesignConnectionListObject.


        :param item_connector_name: The item_connector_name of this CableDesignConnectionListObject.  # noqa: E501
        :type: str
        """

        self._item_connector_name = item_connector_name

    @property
    def md_item_name(self):
        """Gets the md_item_name of this CableDesignConnectionListObject.  # noqa: E501


        :return: The md_item_name of this CableDesignConnectionListObject.  # noqa: E501
        :rtype: str
        """
        return self._md_item_name

    @md_item_name.setter
    def md_item_name(self, md_item_name):
        """Sets the md_item_name of this CableDesignConnectionListObject.


        :param md_item_name: The md_item_name of this CableDesignConnectionListObject.  # noqa: E501
        :type: str
        """

        self._md_item_name = md_item_name

    @property
    def md_connector_name(self):
        """Gets the md_connector_name of this CableDesignConnectionListObject.  # noqa: E501


        :return: The md_connector_name of this CableDesignConnectionListObject.  # noqa: E501
        :rtype: str
        """
        return self._md_connector_name

    @md_connector_name.setter
    def md_connector_name(self, md_connector_name):
        """Sets the md_connector_name of this CableDesignConnectionListObject.


        :param md_connector_name: The md_connector_name of this CableDesignConnectionListObject.  # noqa: E501
        :type: str
        """

        self._md_connector_name = md_connector_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CableDesignConnectionListObject):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CableDesignConnectionListObject):
            return True

        return self.to_dict() != other.to_dict()
