# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.15.4
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class RepresentingAssemblyElementForMachineInformation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'machine_id': 'int',
        'assembly_element_id': 'int',
        'template_match_by_name_for_custom_build': 'bool'
    }

    attribute_map = {
        'machine_id': 'machineId',
        'assembly_element_id': 'assemblyElementId',
        'template_match_by_name_for_custom_build': 'templateMatchByNameForCustomBuild'
    }

    def __init__(self, machine_id=None, assembly_element_id=None, template_match_by_name_for_custom_build=None, local_vars_configuration=None):  # noqa: E501
        """RepresentingAssemblyElementForMachineInformation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._machine_id = None
        self._assembly_element_id = None
        self._template_match_by_name_for_custom_build = None
        self.discriminator = None

        if machine_id is not None:
            self.machine_id = machine_id
        if assembly_element_id is not None:
            self.assembly_element_id = assembly_element_id
        if template_match_by_name_for_custom_build is not None:
            self.template_match_by_name_for_custom_build = template_match_by_name_for_custom_build

    @property
    def machine_id(self):
        """Gets the machine_id of this RepresentingAssemblyElementForMachineInformation.  # noqa: E501


        :return: The machine_id of this RepresentingAssemblyElementForMachineInformation.  # noqa: E501
        :rtype: int
        """
        return self._machine_id

    @machine_id.setter
    def machine_id(self, machine_id):
        """Sets the machine_id of this RepresentingAssemblyElementForMachineInformation.


        :param machine_id: The machine_id of this RepresentingAssemblyElementForMachineInformation.  # noqa: E501
        :type: int
        """

        self._machine_id = machine_id

    @property
    def assembly_element_id(self):
        """Gets the assembly_element_id of this RepresentingAssemblyElementForMachineInformation.  # noqa: E501


        :return: The assembly_element_id of this RepresentingAssemblyElementForMachineInformation.  # noqa: E501
        :rtype: int
        """
        return self._assembly_element_id

    @assembly_element_id.setter
    def assembly_element_id(self, assembly_element_id):
        """Sets the assembly_element_id of this RepresentingAssemblyElementForMachineInformation.


        :param assembly_element_id: The assembly_element_id of this RepresentingAssemblyElementForMachineInformation.  # noqa: E501
        :type: int
        """

        self._assembly_element_id = assembly_element_id

    @property
    def template_match_by_name_for_custom_build(self):
        """Gets the template_match_by_name_for_custom_build of this RepresentingAssemblyElementForMachineInformation.  # noqa: E501


        :return: The template_match_by_name_for_custom_build of this RepresentingAssemblyElementForMachineInformation.  # noqa: E501
        :rtype: bool
        """
        return self._template_match_by_name_for_custom_build

    @template_match_by_name_for_custom_build.setter
    def template_match_by_name_for_custom_build(self, template_match_by_name_for_custom_build):
        """Sets the template_match_by_name_for_custom_build of this RepresentingAssemblyElementForMachineInformation.


        :param template_match_by_name_for_custom_build: The template_match_by_name_for_custom_build of this RepresentingAssemblyElementForMachineInformation.  # noqa: E501
        :type: bool
        """

        self._template_match_by_name_for_custom_build = template_match_by_name_for_custom_build

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RepresentingAssemblyElementForMachineInformation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RepresentingAssemblyElementForMachineInformation):
            return True

        return self.to_dict() != other.to_dict()
