# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.15.4
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class PromoteMachineElementInformation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'parent_md_item_id': 'int',
        'assembly_element_id': 'int',
        'new_name': 'str'
    }

    attribute_map = {
        'parent_md_item_id': 'parentMdItemId',
        'assembly_element_id': 'assemblyElementId',
        'new_name': 'newName'
    }

    def __init__(self, parent_md_item_id=None, assembly_element_id=None, new_name=None, local_vars_configuration=None):  # noqa: E501
        """PromoteMachineElementInformation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._parent_md_item_id = None
        self._assembly_element_id = None
        self._new_name = None
        self.discriminator = None

        if parent_md_item_id is not None:
            self.parent_md_item_id = parent_md_item_id
        if assembly_element_id is not None:
            self.assembly_element_id = assembly_element_id
        if new_name is not None:
            self.new_name = new_name

    @property
    def parent_md_item_id(self):
        """Gets the parent_md_item_id of this PromoteMachineElementInformation.  # noqa: E501


        :return: The parent_md_item_id of this PromoteMachineElementInformation.  # noqa: E501
        :rtype: int
        """
        return self._parent_md_item_id

    @parent_md_item_id.setter
    def parent_md_item_id(self, parent_md_item_id):
        """Sets the parent_md_item_id of this PromoteMachineElementInformation.


        :param parent_md_item_id: The parent_md_item_id of this PromoteMachineElementInformation.  # noqa: E501
        :type: int
        """

        self._parent_md_item_id = parent_md_item_id

    @property
    def assembly_element_id(self):
        """Gets the assembly_element_id of this PromoteMachineElementInformation.  # noqa: E501


        :return: The assembly_element_id of this PromoteMachineElementInformation.  # noqa: E501
        :rtype: int
        """
        return self._assembly_element_id

    @assembly_element_id.setter
    def assembly_element_id(self, assembly_element_id):
        """Sets the assembly_element_id of this PromoteMachineElementInformation.


        :param assembly_element_id: The assembly_element_id of this PromoteMachineElementInformation.  # noqa: E501
        :type: int
        """

        self._assembly_element_id = assembly_element_id

    @property
    def new_name(self):
        """Gets the new_name of this PromoteMachineElementInformation.  # noqa: E501


        :return: The new_name of this PromoteMachineElementInformation.  # noqa: E501
        :rtype: str
        """
        return self._new_name

    @new_name.setter
    def new_name(self, new_name):
        """Sets the new_name of this PromoteMachineElementInformation.


        :param new_name: The new_name of this PromoteMachineElementInformation.  # noqa: E501
        :type: str
        """

        self._new_name = new_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PromoteMachineElementInformation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PromoteMachineElementInformation):
            return True

        return self.to_dict() != other.to_dict()
